#
# spec file for package sysprof
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Bjørn Lie, Bryne, Norway.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sysprof
Version:        3.26.1
Release:        lp150.1.14
Summary:        A system-wide Linux profiler
License:        GPL-3.0+
Group:          Development/Tools/Debuggers
Url:            http://www.sysprof.com
Source0:        http://download.gnome.org/sources/sysprof/3.26/%{name}-%{version}.tar.xz
BuildRequires:  binutils-devel
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  gobject-introspection-devel
BuildRequires:  itstool
BuildRequires:  libxml2-tools
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gio-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.21.5
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(polkit-gobject-1)
Requires:       hicolor-icon-theme
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Sysprof is a sampling CPU profiler for Linux that collects accurate,
high-precision data and provides efficient access to the sampled
calltrees.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%lang_package

%prep
%setup -q

%build
%configure --disable-static --disable-Werror
make %{?_smp_mflags}

%install
%make_install DESTDIR=%{buildroot} %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file org.gnome.Sysprof2 Profiling

%pre
%service_add_pre sysprof2.service

%preun
%service_del_preun sysprof2.service

%post
/sbin/ldconfig
%desktop_database_post
%icon_theme_cache_post
%service_add_post sysprof2.service

%postun
/sbin/ldconfig
%desktop_database_postun
%icon_theme_cache_postun
%service_del_postun sysprof2.service

%files
%defattr(-,root,root)
%doc README COPYING NEWS TODO AUTHORS
%{_bindir}/sysprof
%{_bindir}/sysprof-cli
%{_libdir}/libsysprof-2.so
%{_libdir}/libsysprof-ui-2.so
%dir %{_libexecdir}/sysprof
%{_libexecdir}/sysprof/sysprofd
%{_datadir}/appdata/org.gnome.Sysprof2.appdata.xml
%{_datadir}/applications/*.desktop
%dir %{_datadir}/dbus-1/system.d
%{_datadir}/dbus-1/system.d/org.gnome.Sysprof2.conf
%{_datadir}/dbus-1/system-services/org.gnome.Sysprof2.service
%{_datadir}/glib-2.0/schemas/org.gnome.sysprof2.gschema.xml
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/mime/packages/sysprof-mime.xml
%{_datadir}/polkit-1/actions/org.gnome.sysprof2.policy
%{_unitdir}/sysprof2.service
%dir %{_datadir}/help/C/sysprof
%{_datadir}/help/C/sysprof/*

%files devel
%defattr(-,root,root)
%{_includedir}/sysprof-2/
%{_libdir}/pkgconfig/sysprof-2.pc
%{_libdir}/pkgconfig/sysprof-ui-2.pc

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Thu Oct  5 2017 dimstar@opensuse.org
- Update to version 3.26.1:
  + Add missing FAQ to help documentation.
* Sat Sep 16 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + No changes, stable bump only.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Additional help topics.
  + Fix for a potential divide-by-zero when generating callgraphs.
  + Alignment attributes to allow building on armel/armhf/mipsel.
  + About dialog is now modal.
  + Each new Sysprof window gets its own window group.
  + Updated translations.
* Tue Apr 25 2017 dimstar@opensuse.org
- Update to version 3.24.1:
  + About dialog is now modal to it's direct parent only.
  + Updated translations.
* Mon Mar 20 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Use gtk_show_uri_on_window() to improve help window placement
    on Wayland.
  + Updated translations.
* Tue Mar 14 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + Compilation fix for 32-bit ARM.
  + Updated translations.
* Wed Mar  1 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Various compilation checks based on results from ARM builders.
  + Support for setting symbol directories to affect symbol
    resolution.
  + Translate paths from /newroot/ into the host filesystem when
    possible. This should allow some degree of profiling
    container-based applications and still resolve symbols on the
    host. Builder does this now when profiling Flatpak-based
    applications.
  + Updated translations.
* Sat Feb 18 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Build system support for Meson.
  + Appdata support has been added.
  + Desktop file can be translated.
  + Updated translations.
* Wed Nov 30 2016 zaitor@opensuse.org
- Update to version 3.22.3:
  + Fix expansion of function text in callgraph.
  + Fix jump-to-function in callees list.
  + Disable record button while generating callgraph profile.
  + Ensure sysprof icons are available form libsysprof-ui-2.
  + sysprof-cli requires --force to overwrite previous capture.
  + Reduce code duplication in capture frame initialization.
  + Updated translations.
* Wed Nov  2 2016 zaitor@opensuse.org
- Update to version 3.22.2:
  + ftruncate() when creating a capture in case we overwrite a
    previous capture file. This ensures we don't leave junk at the
    end of the capture.
  + Handle EAGAIN when writing the opportunistic end-time header.
  + Capture cursor should short circuit when no read delegate was
    found.
  + Updated translations.
* Sat Oct 15 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + A new data source called "hostinfo" has been added. It records
    various CPU datapoints as "counters" in the sysprof capture.
  + A new visualizers abstraction has been added so that we can
    start providing new ways to look at profiler data.
  + A CPU visualizer has been added which renders datapoints
    recorded from the hostinfo data source.
  + Selecting ranges of the visualizer will update the callgraph
    limiting stacktrace samples, to the given time range.
  + Missing headers are now installed which may be needed by
    applications using libsysprof-ui.
  + A keyboard shortcuts dialog has been added.
  + A theme manager has been added to allow us to provide custom
    CSS for various themes. Currently, we have additional styling
    added for Adwaita and Adwaita-dark.
  + Updated translations.
- Pass --disable-Werror to configure, we do not need to handle
  warnings as errors.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Fri Sep  2 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Allow collapsing the callgraph tree with Left arrow.
  + Add a full barrier before writing data_tail as suggested by
    Perf kernel documentation.
  + Support for additional architectures has been enabled by the
    use of C11 atomics.
  + Require -std=gnu11 for stdatomic.h.
  + Correct gettext domain for translation files.
- Drop sysprof-correct-gettext-domain.patch: Fixed upstream.
* Sat Aug 27 2016 zaitor@opensuse.org
- Initial package, version 3.21.90.
